# SC16739_7segment_display class test, demo and example script
# Copyright 2022 Любезный В. В.
# This script is licensed under Mozilla public license, version 2.0
# https://www.mozilla.org/en-US/MPL/2.0/
# Version 1.0
# Last change: April 3, 2022

import RPi.GPIO as GPIO
import time
from classes import SC16739_7segment_display

print('SC16739_7segment_display class test, demo and example script')
print('Copyright 2022 Victor Lyubeznyy')
print('This script is licensed under Mozilla public license, version 2.0')
print('https://www.mozilla.org/en-US/MPL/2.0/')
print('')
print('Please be sure that you have defined GPIO settings and transmission '
    + 'sequence in this script before executing command. Otherwise, press '
    + 'Enter to quit')

# Creating display object
display = SC16739_7segment_display.SC16739_7segment_display(
    {
        # GPIO mode and pin numbers
        'MODE': GPIO.BOARD,
        'DCLK': 13,
        'LATCH': 15,
        'OE': 16,
        'SDI': 18
    }, [
        # Segment information transmission sequence.
        'P5', 'G5', 'F5', 'E5', 'D5', 'C5', 'B5', 'A5',
        'P4', 'G4', 'F4', 'E4', 'D4', 'C4', 'B4', 'A4',
        'P3', 'G3', 'F3', 'E3', 'D3', 'C3', 'B3', 'A3',
        'P2', 'G2', 'F2', 'E2', 'D2', 'C2', 'B2', 'A2',
        'P1', 'G1', 'F1', 'E1', 'D1', 'C1', 'B1', 'A1',
        'P0', 'G0', 'F0', 'E0', 'D0', 'C0', 'B0', 'A0'
    ], False)

# Main endless working cycle
while True:
    print('Commands:')
    print('    1 - Test segments ignition one by one')
    print('    2 - Test text output')
    print('    3 - Blink point segments')
    cmd = input('Enter command (or just nothing to quit), then press Enter: ')
    if (cmd == ''):
        break
    # Turning display on
    display.on_off(True)

    # Interpreting commands
    if (cmd == '1'):
        # Command 1 - Test segments ignition one by one
        # Displaying information for user
        print('Segments letter definition:')
        print('    __A__')
        print('   |     |')
        print('   |F    |B')
        print('   |__G__|')
        print('   |     |')
        print('   |E    |C')
        print('   |__D__| .P')
        print('The first left-side digit index is 0')

        # A variable to store the previous ignited segment
        prev_segment = 'A0'
        # Working cycle
        for segment in display.transmission_sequence:
            display.set_segment_state(prev_segment, False)
            display.set_segment_state(segment, True)
            display.send_output(True)
            prev_segment = segment
            print('Segment ' + segment + ' is on')
            cmd = input('Press Enter to continue, or type something '
                + 'and press Enter to break. ')
            if (cmd != ''):
                break
    if (cmd == '2'):
        # Command 2 - test text output
        # Defining non-empty variable to store user input
        string = '1'
        # Command working cycle - repeat until the line is empty
        while string != '':
            # Request the line
            string = input(
                'Enter string and press Enter (or press Enter'
                + ' to break): ')
            # Display entered line
            display.display_string(string)

    if (cmd == '3'):
        # Command 3 - blink point segments
        print('Press Ctrl+C to exit and terminate script')
        # Variable to store previous digit index
        prev_digit = 0
        # Endless working cycle
        while True:
            # Digit enumeration cycle
            for i in range(0, display.digits_count):
                # Turn previous point off
                display.set_point(prev_digit, False)
                # Turn next point on
                display.set_point(i, True)
                # Set previous point index
                prev_digit = i
                # Delay 1 second
                time.sleep(1)
